==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/ValueReferenceBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValueReferenceBuilder extends io.dekorate.helm.config.ValueReferenceFluentImpl<io.dekorate.helm.config.ValueReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.helm.config.ValueReference,io.dekorate.helm.config.ValueReferenceBuilder>{
  public ValueReferenceBuilder() {
    this(false);
  }
  public ValueReferenceBuilder(java.lang.Boolean validationEnabled) {
    this(new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,io.dekorate.helm.config.ValueReference instance) {
    this(fluent, instance, false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,io.dekorate.helm.config.ValueReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withJsonPaths(instance.getJsonPaths()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReference instance) {
    this(instance,false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withJsonPaths(instance.getJsonPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.ValueReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.helm.config.EditableValueReference build() {
    EditableValueReference buildable = new EditableValueReference(fluent.getProperty(),fluent.getJsonPaths(),fluent.getProfile(),fluent.getValue());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueReferenceBuilder that = (ValueReferenceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> helm-annotations-2.9.2-sources.jar: io/dekorate/helm/config/ValueReferenceBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValueReferenceBuilder extends ValueReferenceFluentImpl<ValueReferenceBuilder> implements VisitableBuilder<ValueReference,io.dekorate.helm.config.ValueReferenceBuilder>{
  public ValueReferenceBuilder() {
    this(false);
  }
  public ValueReferenceBuilder(Boolean validationEnabled) {
    this(new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(ValueReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ValueReference(), validationEnabled);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,io.dekorate.helm.config.ValueReference instance) {
    this(fluent, instance, false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReferenceFluent<?> fluent,io.dekorate.helm.config.ValueReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withJsonPaths(instance.getJsonPaths()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReference instance) {
    this(instance,false);
  }
  public ValueReferenceBuilder(io.dekorate.helm.config.ValueReference instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withJsonPaths(instance.getJsonPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.helm.config.ValueReferenceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableValueReference build() {
    EditableValueReference buildable = new EditableValueReference(fluent.getProperty(),fluent.getJsonPaths(),fluent.getProfile(),fluent.getValue());
    return buildable;
  }
  
}
